@@ -9,19 +9,27 @@ django.setup()
 from c_mssql import DB_Config
 from c_mssql.mssql_conn import Mssql_Conn
 
+import io,json,os
+
+
+
+
+def add_sql_description(table_name,description,column_name=None):
+    table_str="INNER JOIN sys.columns AS c ON t.object_id = c.object_id" if bool(column_name) else ""
+    join_str=" AND ep.minor_id = c.column_id " if bool(column_name) else " and ep.minor_id=0 "
+    where_str=f"AND C.name= '{column_name}'" if bool(column_name) else ""
+    update_str=f""",@level2type = N'Column', @level2name = '{column_name}'""" if bool(column_name) else ""
 
-def add_sql_description(table_name,column_name,description):
     sql_str=f"""
 IF EXISTS(
 SELECT top 1 1
 FROM sys.tables AS t
-INNER JOIN sys.columns
-AS c ON t.object_id = c.object_id
+{table_str}
 inner JOIN sys.extended_properties AS ep
-ON ep.major_id = c.object_id AND ep.minor_id = c.column_id and ep.class =1
+ON ep.major_id = t.object_id  {join_str} and ep.class =1
 WHERE 1=1
 AND t.name='{table_name}' 
-AND C.name= '{column_name}'
+{where_str}
 AND EP.class=1
 )
 BEGIN
@@ -29,8 +37,8 @@ EXEC sp_updateextendedproperty
 @name = N'MS_Description',   
 @value = '{description}',  
 @level0type = N'Schema', @level0name = 'dbo',  
-@level1type = N'Table',  @level1name = '{table_name}',  
-@level2type = N'Column', @level2name = '{column_name}'; 
+@level1type = N'Table',  @level1name = '{table_name}'  
+{update_str};
 END
 ELSE
 BEGIN
@@ -38,11 +46,12 @@ EXEC sp_addextendedproperty
 @name = N'MS_Description',   
 @value = '{description}',  
 @level0type = N'Schema', @level0name = 'dbo',  
-@level1type = N'Table',  @level1name = '{table_name}',  
-@level2type = N'Column', @level2name = '{column_name}'; 
+@level1type = N'Table',  @level1name = '{table_name}'
+{update_str};
 END
  
 """
+    # print(sql_str)
     server=settings.DATABASES["default"]["HOST"]
     database=settings.DATABASES["default"]["NAME"]
     username=settings.DATABASES["default"]["USER"]
@@ -54,15 +63,17 @@ END
     conn.close()
 
 
-def update_MS_Description(models):
+def update_MS_Description(models,modelname="project.models"):
     data_list=[]
     for key in dir(models):
         model=getattr(models,key)
         try:
-            if model.__module__=="project.models":
+            if model.__module__==modelname:
                 model_name=key
                 model=model
-                table_name=model.__dict__["_meta"].db_table
+                table_name=model._meta.db_table
+                row_dict={"table_name":model._meta.db_table,"field_name":None,"verbose_name":model._meta.verbose_name}
+                data_list.append(row_dict)
                 filed_str=model.__doc__
                 filed_str=filed_str[len(model_name)+1:len(filed_str)-1]
                 for field in filed_str.split(","):
@@ -79,6 +90,6 @@ def update_MS_Description(models):
 
     for row_dict in data_list:
         print("正在更新:",row_dict)
-        add_sql_description(row_dict["table_name"],row_dict["field_name"],row_dict["verbose_name"])
+        add_sql_description(row_dict["table_name"],row_dict["verbose_name"],row_dict["field_name"])
     print("更新成功")
-    
\ No newline at end of file
+    
